import paleomix.ui
import paleomix.config
import paleomix.nodes.misc
import paleomix.nodes.bwa
import paleomix.nodes.picard
import paleomix.nodes.adapterremoval
import paleomix.nodes.commands
import paleomix.nodes.examl
import paleomix.nodes.formats
import paleomix.nodes.newick
import paleomix.nodes.samtools
import paleomix.nodes.gatk
import paleomix.nodes.validation
import paleomix.nodes.bedtools
import paleomix.nodes.mafft
import paleomix.nodes.sequences
import paleomix.nodes.phylip
import paleomix.nodes.raxml
import paleomix.nodes.bowtie2
import paleomix.nodes.mapdamage
import paleomix.logger
import paleomix.common.timer
import paleomix.common.makefile
import paleomix.common.utilities
import paleomix.common.formats.msa
import paleomix.common.formats.fasta
import paleomix.common.formats._graph
import paleomix.common.formats.newick
import paleomix.common.formats._common
import paleomix.common.formats.fastq
import paleomix.common.formats.phylip
import paleomix.common.vcfwrap
import paleomix.common.rtools
import paleomix.common.testing
import paleomix.common.sampling
import paleomix.common.vcffilter
import paleomix.common.procs
import paleomix.common.fileutils
import paleomix.common.signals
import paleomix.common.console
import paleomix.common.versions
import paleomix.common.bedtools
import paleomix.common.sequences
import paleomix.common.system
import paleomix.common.text
import paleomix.common.bamfiles
import paleomix.atomiccmd.command
import paleomix.atomiccmd.pprint
import paleomix.atomiccmd.sets
import paleomix.atomiccmd.builder
import paleomix.tools.zonkey.parts.summary
import paleomix.tools.zonkey.parts.report
import paleomix.tools.zonkey.parts.nuclear
import paleomix.tools.zonkey.parts.common
import paleomix.tools.zonkey.parts.mitochondria
import paleomix.tools.zonkey.parts.admixture
import paleomix.tools.zonkey.config
import paleomix.tools.zonkey.build_db
import paleomix.tools.zonkey.database
import paleomix.tools.zonkey.build_mito
import paleomix.tools.zonkey.pipeline
import paleomix.tools.zonkey.build_tped
import paleomix.tools.zonkey.common
import paleomix.tools.bam_stats.coverage
import paleomix.tools.bam_stats.common
import paleomix.tools.duphist
import paleomix.tools.genotype
import paleomix.tools.rmdup_collapsed
import paleomix.tools.bam_pipeline.parts.summary
import paleomix.tools.bam_pipeline.parts.lane
import paleomix.tools.bam_pipeline.parts.prefix
import paleomix.tools.bam_pipeline.parts.target
import paleomix.tools.bam_pipeline.parts.statistics
import paleomix.tools.bam_pipeline.parts.sample
import paleomix.tools.bam_pipeline.parts.library
import paleomix.tools.bam_pipeline.parts.reads
import paleomix.tools.bam_pipeline.mkfile
import paleomix.tools.bam_pipeline.config
import paleomix.tools.bam_pipeline.makefile
import paleomix.tools.bam_pipeline.nodes
import paleomix.tools.bam_pipeline.trim_pipeline
import paleomix.tools.bam_pipeline.paths
import paleomix.tools.bam_pipeline.pipeline
import paleomix.tools.bam_pipeline.remap
import paleomix.tools.depths
import paleomix.tools.phylo_pipeline.parts.msa
import paleomix.tools.phylo_pipeline.parts.genotype
import paleomix.tools.phylo_pipeline.parts.phylo
import paleomix.tools.phylo_pipeline.parts.paml
import paleomix.tools.phylo_pipeline.mkfile
import paleomix.tools.phylo_pipeline.config
import paleomix.tools.phylo_pipeline.makefile
import paleomix.tools.phylo_pipeline.pipeline
import paleomix.tools.coverage
import paleomix.tools.vcf_to_fasta
import paleomix.tools.ena
import paleomix.tools.cleanup
import paleomix.tools.gtf_to_bed
import paleomix.tools.cat
import paleomix.tools.factory
import paleomix.tools.vcf_filter
import paleomix.tools.dupcheck
import paleomix.tools.retable
import paleomix.tools.sample_pileup
import paleomix.pipeline
import paleomix.node
import paleomix.main
import paleomix.nodegraph



#!/usr/bin/python
#
# Copyright (c) 2013 Mikkel Schubert <MikkelSch@gmail.com>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
import os
import sys
import resource


def set_procname(name=os.path.basename(sys.argv[0])):
    """Attempts to set the current process-name to the given name."""
    import setproctitle

    setproctitle.setproctitle(name)


def get_max_open_files():
    """Returns the maximum number of open files per process
    (soft limit) or None if this could not be determined.
    """
    soft_limit = None

    try:
        key = resource.RLIMIT_NOFILE
    except AttributeError:
        try:
            key = resource.RLIMIT_OFILE
        except AttributeError:
            return

    try:
        soft_limit, _ = resource.getrlimit(key)
    except resource.error:
        pass

    return soft_limit
